/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.services;

import org.ow2.bonita.facade.def.majorElement.ProcessFullDefinition;
import org.ow2.bonita.facade.runtime.ProcessFullInstance;

/**
 * An Archiver is responsible for archiving <strong>non-runtime</strong> instances
 * such as undeployed pakages and processes, dead instances, activities and tasks.
 *
 * Usually, archived records are available using queries on an {@link History}.
 *
 * @author Pierre Vigneras
 * @date Feb 6, 2008
 * @see History
 *
 */
public interface Archiver extends Clearable {

  String DEFAULT_KEY = "archiver";

  void archive(ProcessFullDefinition processDeef);
  void archive(ProcessFullInstance processInst);
  
  /**
   * Generic method for removing a history record.
   *
   * Implementation may delegate to overloaded methods according to record type.
   * @param record the record to archive
   * @return true if removing was possible, false otherwise.
   */
  void remove(ProcessFullInstance processInst);
  void remove(ProcessFullDefinition processDef);
}
